@@ -12,12 +12,12 @@ const babelRuntimeVersion = pkg.dependencies['@babel/runtime'].replace(
   ''
 )
 
-const makeExternalPredicate = externalArr => {
+const makeExternalPredicate = (externalArr) => {
   if (externalArr.length === 0) {
     return () => false
   }
   const pattern = new RegExp(`^(${externalArr.join('|')})($|/)`)
-  return id => pattern.test(id)
+  return (id) => pattern.test(id)
 }
 
 export default [
@@ -27,21 +27,21 @@ export default [
     output: { file: 'lib/redux.js', format: 'cjs', indent: false },
     external: makeExternalPredicate([
       ...Object.keys(pkg.dependencies || {}),
-      ...Object.keys(pkg.peerDependencies || {})
+      ...Object.keys(pkg.peerDependencies || {}),
     ]),
     plugins: [
       nodeResolve({
-        extensions
+        extensions,
       }),
       babel({
         extensions,
         plugins: [
           ['@babel/plugin-transform-runtime', { version: babelRuntimeVersion }],
-          ['./scripts/mangleErrors.js', { minify: false }]
+          ['./scripts/mangleErrors.js', { minify: false }],
         ],
-        babelHelpers: 'runtime'
-      })
-    ]
+        babelHelpers: 'runtime',
+      }),
+    ],
   },
 
   // ES
@@ -50,24 +50,24 @@ export default [
     output: { file: 'es/redux.js', format: 'es', indent: false },
     external: makeExternalPredicate([
       ...Object.keys(pkg.dependencies || {}),
-      ...Object.keys(pkg.peerDependencies || {})
+      ...Object.keys(pkg.peerDependencies || {}),
     ]),
     plugins: [
       nodeResolve({
-        extensions
+        extensions,
       }),
       babel({
         extensions,
         plugins: [
           [
             '@babel/plugin-transform-runtime',
-            { version: babelRuntimeVersion, useESModules: true }
+            { version: babelRuntimeVersion, useESModules: true },
           ],
-          ['./scripts/mangleErrors.js', { minify: false }]
+          ['./scripts/mangleErrors.js', { minify: false }],
         ],
-        babelHelpers: 'runtime'
-      })
-    ]
+        babelHelpers: 'runtime',
+      }),
+    ],
   },
 
   // ES for Browsers
@@ -76,26 +76,28 @@ export default [
     output: { file: 'es/redux.mjs', format: 'es', indent: false },
     plugins: [
       nodeResolve({
-        extensions
+        extensions,
       }),
       replace({
-        'process.env.NODE_ENV': JSON.stringify('production')
+        'process.env.NODE_ENV': JSON.stringify('production'),
+        preventAssignment: false,
       }),
       babel({
         extensions,
         exclude: 'node_modules/**',
         plugins: [['./scripts/mangleErrors.js', { minify: true }]],
-        skipPreflightCheck: true
+        skipPreflightCheck: true,
+        babelHelpers: 'bundled',
       }),
       terser({
         compress: {
           pure_getters: true,
           unsafe: true,
           unsafe_comps: true,
-          warnings: false
-        }
-      })
-    ]
+          warnings: false,
+        },
+      }),
+    ],
   },
 
   // UMD Development
@@ -105,21 +107,23 @@ export default [
       file: 'dist/redux.js',
       format: 'umd',
       name: 'Redux',
-      indent: false
+      indent: false,
     },
     plugins: [
       nodeResolve({
-        extensions
+        extensions,
       }),
       babel({
         extensions,
         exclude: 'node_modules/**',
-        plugins: [['./scripts/mangleErrors.js', { minify: false }]]
+        plugins: [['./scripts/mangleErrors.js', { minify: false }]],
+        babelHelpers: 'bundled',
       }),
       replace({
-        'process.env.NODE_ENV': JSON.stringify('development')
-      })
-    ]
+        'process.env.NODE_ENV': JSON.stringify('development'),
+        preventAssignment: false,
+      }),
+    ],
   },
 
   // UMD Production
@@ -129,29 +133,31 @@ export default [
       file: 'dist/redux.min.js',
       format: 'umd',
       name: 'Redux',
-      indent: false
+      indent: false,
     },
     plugins: [
       nodeResolve({
-        extensions
+        extensions,
       }),
       babel({
         extensions,
         exclude: 'node_modules/**',
         plugins: [['./scripts/mangleErrors.js', { minify: true }]],
-        skipPreflightCheck: true
+        skipPreflightCheck: true,
+        babelHelpers: 'bundled',
       }),
       replace({
-        'process.env.NODE_ENV': JSON.stringify('production')
+        'process.env.NODE_ENV': JSON.stringify('production'),
+        preventAssignment: false,
       }),
       terser({
         compress: {
           pure_getters: true,
           unsafe: true,
           unsafe_comps: true,
-          warnings: false
-        }
-      })
-    ]
-  }
+          warnings: false,
+        },
+      }),
+    ],
+  },
 ]
