@@ -1,4 +1,4 @@
 export function thunk({ dispatch, getState }) {
-  return next => action =>
+  return (next) => (action) =>
     typeof action === 'function' ? action(dispatch, getState) : next(action)
 }
